# Axonius Slack Bot

This is a [Slack bot](https://api.slack.com/bot-users) for [Axonius](https://axonius.com). It enables users in Slack to interact with an Axonius instance in a number of ways:
* Get a JSON report of objects. 
* You can search for user objects by username, email (using regex or not).
* You can search for device objects by hostname, IP address, or MAC address (using regex or not).
* You can search for user or device objects by a query built in the Query Wizard of the Axonius GUI.
* You can add or remove labels in the thread that is started up for returned objects.

Documentation can be found [here](https://github.com/Axonius/axonbot_slack/blob/master/docs/README.md).

For questions, feature requests, or bug reports, you can:
* File an issue on the [Issue Tracker](https://github.com/Axonius/axonbot_slack/issues)
* Email apiclient@axonius.com
